@@ -1,5 +1,10 @@
 # Author: Martin Matusiak <numerodix@gmail.com>
 
+from __future__ import absolute_import
+
+import pprint
+import types
+
 
 __all__ = [
     'Dumper',
@@ -7,11 +12,6 @@ __all__ = [
 ]
 
 
-import pprint
-import re
-import types
-
-
 try:
     basestring = basestring
 except NameError:
@@ -27,7 +27,8 @@ class Dumper(object):
         try:
             hash(obj)
             return True
-        except TypeError: pass
+        except TypeError:
+            pass
 
     def is_iterable(self, obj):
         '''strings are iterable too, therefore check against basestring'''
@@ -35,26 +36,27 @@ class Dumper(object):
             try:
                 iter(obj)
                 return True
-            except TypeError: pass
+            except TypeError:
+                pass
 
     def has_repr(self, obj):
         # short circuit here to prevent eval on module
-        if type(obj) == types.ModuleType:
+        if isinstance(obj, types.ModuleType):
             return True
 
         try:
             eval(repr(obj))
             return True
-        except: pass
+        except:
+            pass
 
     def is_reference_type(self, obj):
         return self.is_hashable(obj) and not self.has_repr(obj)
 
     def is_dicty(self, obj):
-        if hasattr(obj, 'keys') and obj.keys(): # if no keys do iter
+        if hasattr(obj, 'keys') and obj.keys():  # if no keys do iter
             return True
 
-
     def get_object_id(self, obj):
         if obj not in self.index:
             self.index[obj] = len(self.index)
@@ -79,12 +81,12 @@ class Dumper(object):
 
         # filter callables
         # check for obj.member.__call__
-        atts_instance = filter(lambda m: not hasattr(getattr(obj, m), '__call__'),
-                               atts_instance)
+        atts_instance = filter(
+            lambda m: not hasattr(getattr(obj, m), '__call__'),
+            atts_instance)
 
         return atts_instance
 
-
     def dump_dicty(self, obj, visited):
         dct = {}
         for key in obj.keys():
@@ -101,10 +103,13 @@ class Dumper(object):
     def dump_instance(self, obj, visited, norec=False):
         atts = self.get_own_atts(obj)
         ret = {}
+
         name = self.get_object_name(obj)
         if name:
-            ret['__name__'] = name
-        ret['__type__'] = self.get_type_name(obj)
+            ret['___name___'] = name
+
+        ret['___type___'] = self.get_type_name(obj)
+
         for att in atts:
             val = getattr(obj, att)
             ret[att] = val
@@ -113,7 +118,7 @@ class Dumper(object):
         return ret
 
     def dump_repr(self, obj, visited):
-        if type(obj) == types.ModuleType:
+        if isinstance(obj, types.ModuleType):
             return self.dump_instance(obj, visited, norec=True)
 
         return repr(obj)
